The Investigatory Powers Tribunal is an independent court that considers complaints under the Regulation of Investigatory Powers Act 2000 and claims under the Human Rights Act 1998. It considers allegations of unlawful intrusion by public bodies, including the UK intelligence services, the Police and local authorities and investigates alleged conduct by or on behalf of the UK intelligence services whether or not it involves investigatory powers.

This tribunal began to regularly transfer judgments to The National Archives in 2024. The oldest decision from this tribunal included in Find Case Law is from {start_year}.

You can read more about this tribunal on [the Investigatory Powers Tribunal website](https://investigatorypowerstribunal.org.uk/about-the-tribunal/){target="\_blank"}.
